@@ -1,5 +1,5 @@
 (function(program, execJS) { execJS(program) })(function() {
-  return eval(#{encoded_source});
+  return eval(#{encode_source(source)});
 }, function(program) {
   var output;
   try {
